Learn R Programming

bitfield (version 1.0.0)

.toBin: Make a binary value from an integer

Description

Make a binary value from an integer

Usage

.toBin(x, len = NULL, pad = TRUE)

Arguments

x

numeric(.)
numeric vector for which to derive the binary values.

len

integerish(1)
the number of bits used to capture each value. If NULL, computed from the maximum value.

pad

logical(1)
whether to pad the binary values with leading zeros to equal width.