| registry-class | R Documentation |
A registry stores metadata and flag configuration of a bitfield.
widthintegerish(1)
how many bits is the bitfield wide.
lengthintegerish(1)
how many observations are encoded
in the bitfield.
namecharacter(1)
short name of the bitfield.
versioncharacter(1)
automatically created version
tag of the bitfield. This consists of the package version, the version of R
and the date of creation of the bitfield.
md5character(1)
the MD5 checksum of the bitfield as
determined with md5sum.
descriptioncharacter(1)
longer description of the
bitfield.
flagslist(.)
list of flags in the registry.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.