| bf_encode | R Documentation |
This function picks up the flags mentioned in a registry and encodes them as integer values.
bf_encode(registry)
registry |
|
data.frame of the same length as the input data. Depending on type and amount of bit flags, this can a table with any number of columns, each of which encodes a sequence of 32 bits into an integer.
reg <- bf_map(protocol = "na", data = bf_tbl, x = y)
field <- bf_encode(registry = reg)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.